@@ -373,11 +373,13 @@ class TestGetinfo(base.TestCase):
                    "dlrn.drivers.rdoinfo.RdoInfoDriver")
         self.config = ConfigOptions(config)
 
+    @mock.patch('dlrn.drivers.rdoinfo.RdoInfoDriver._distgit_setup',
+                return_value=True)
     @mock.patch.object(sh.Command, '__call__', autospec=True,
                        side_effect=_mocked_git_log)
     @mock.patch('dlrn.drivers.rdoinfo.refreshrepo',
                 side_effect=_mocked_refreshrepo)
-    def test_getinfo_basic(self, rr_mock, git_mock, db_mock):
+    def test_getinfo_basic(self, rr_mock, git_mock, db_mock, ds_mock):
         driver = RdoInfoDriver(cfg_options=self.config)
         package = {
             'name': 'openstack-nova',
@@ -403,9 +405,11 @@ class TestGetinfo(base.TestCase):
         self.assertEqual(len(project_toprocess), 1)
         self.assertEqual(skipped, False)
 
+    @mock.patch('dlrn.drivers.rdoinfo.RdoInfoDriver._distgit_setup',
+                return_value=True)
     @mock.patch('dlrn.drivers.rdoinfo.refreshrepo',
                 side_effect=Exception('Failed to clone git repository'))
-    def test_getinfo_failure(self, rr_mock, db_mock):
+    def test_getinfo_failure(self, rr_mock, db_mock, ds_mock):
         driver = RdoInfoDriver(cfg_options=self.config)
         package = {
             'name': 'openstack-nova',
